Clazz.declarePackage("JV");
Clazz.declareInterface(JV, "JmolChimeMessenger");
;//5.0.1-v7 Mon Jan 19 16:49:55 CST 2026
